#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Project       FreeImagePy
# file name:    setup.py
# Version:      2.0.0
#
# DESCRIPTION
# FreeImage python bind - setup.py
#
# Developer:
# Michele Petrazzo <michele.petrazzo@unipex.it>
#
# History:
# creation: 08/2005 - Michele Petrazzo
# see Changelog.txt or other
#
# License:
#         GNU General Public License (GPL)
#         FreeImage Public License (FIPL)
#         For more info see LICENSE.txt
#
# Copyright (C) 2005  Unipex s.r.l.,  All Rights Reserved.
# Via Vittorio Veneto 83/A
# 33050 Gonars (UD) - Italy
# tel. +39 0432 931511 - fax +39 0432 931378
# www.unipex.it - michele.petrazzo@unipex.it
#


from distutils.core import setup
import os, sys
import glob, shutil

package_name = "FreeImagePy"

PY3 = sys.version_info[0] > 2
if PY3:
    str_skip = "py2.py"
else:
    str_skip = "py3.py"

#make users happy
if len(sys.argv) == 1: 
    sys.argv.append("install")

for f_path in os.listdir(package_name):
    #control and move file, avoiding python [2|3] incompatibility errors
    if str_skip in f_path:
        file_complete = os.path.join(package_name, f_path)
        file_complete_to = os.path.join(package_name, "data", f_path)
        shutil.move(file_complete, file_complete_to)

dataToCopy = glob.glob("FreeImagePy/data/*.*")
dataForTest = ["%s/test/freeimage.jpg" % package_name]
dataForTool = ["%s/tools/functList.txt" % package_name]


if sys.platform == 'win32': 
    prefix = os.path.join(sys.prefix, "Lib/site-packages/%s" % package_name)
else: 
    prefix = os.path.join(sys.exec_prefix, "lib/python%s" % sys.version[:3], "site-packages/%s" % package_name)

dirTest = os.path.join(prefix, "test")
dirTool = os.path.join(prefix, "tools")

setup(
    name='FreeImagePy',
    version='2.0.0',
    description='Python binding for FreeImage library',
    author='Michele Petrazzo - Unipex srl',
    author_email='michele.petrazzo@unipex.it',
    url='http://freeimage.sf.net',
    license='GNU General Public License v2, FreeImage Public License',
    packages=['FreeImagePy', 'FreeImagePy.test', 'FreeImagePy.tools'],
    data_files=[ (prefix, dataToCopy),
                 (dirTest, dataForTest),
                 (dirTool, dataForTool),
               ],
)

for f_path in os.listdir(os.path.join(package_name, "data")):
    #do the reverse work
    if str_skip in f_path:
        file_complete_from = os.path.join(package_name, "data", f_path)
        file_complete_to = os.path.join(package_name, f_path)
        shutil.move(file_complete_from, file_complete_to)
